@@ -14,6 +14,15 @@ logger = logging.getLogger(__name__)
 class FeedConfig:
     name: str
     source: str
+    save_bandwith: bool = True
+    footer: bool = True
+    footer_name: Optional[str] = None
+    footer_link: Optional[str] = None
+    etag: Optional[str] = None
+    modified: Optional[str] = None
+    web_page_preview: Optional[bool] = None
+    read_more_button: Optional[str] = None
+    message_delay: Optional[float] = None
     cache: Optional[str] = None
 
     def __str__(self):
@@ -24,7 +33,11 @@ class FeedConfig:
 class Config:
     bot_token: str = ""
     env_token: str = "TOKEN"
+    web_page_preview: bool = True
     message_delay: float = 0.05
+    author_text: str = "Author"
+    read_more_button: str = "Read more..."
+    channel_text: str = "Channel"
     config_dir: str = _get_default_directory()
     data_dir: str = _get_default_directory("data")
     users: List[int] = attr.ib(factory=list)
